<?php

namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Teknisa\Libs\Service\CRUD;
use Teknisa\Libs\Util\Environment;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\SM\Service\Sm00001002DocumentoPropostaIdiomaService;
use Teknisa\SM\Service\Sm00001001DocumentoPropostaService;
use Zeedhi\Framework\Remote\FileUploader\Server;

class Sm00001002DocumentoPropostaIdiomaController extends SMCrud {
    
    protected $dataSourceName = "fct_orcamentodocidioma_completo";
    protected $docIdiomaService;
    protected $zhFileUploader;
    protected $documentoPropostaService;

    public function __construct(CRUD $crudService, Environment $environment, Sm00001002DocumentoPropostaIdiomaService $docIdiomaService, Server $zhFileUploader, Sm00001001DocumentoPropostaService $documentoPropostaService) {
        parent::__construct($crudService, $environment);
        $this->docIdiomaService         = $docIdiomaService;
        $this->zhFileUploader           = $zhFileUploader;
        $this->documentoPropostaService = $documentoPropostaService;
    }

    /**
     * @param Request\DataSet $request
     * @param Response $response
     */
    public function save(Request $request, Response $response) {
        try {
            foreach ($request->getDataSet()->getRows() as &$row) {
                if (isset($row["DSCAMINHOARQ"]) && is_array($row["DSCAMINHOARQ"])) {
                    $row["NMARQUIVO"]    = $row["DSCAMINHOARQ"][0]["name"];
                    $row["VRTAMANHO"]    = round($row["DSCAMINHOARQ"][0]["size"] / 1024, 2);
                    $row["DSTIPO"]       = ($row["DSCAMINHOARQ"][0]["type"]) ? $row["DSCAMINHOARQ"][0]["type"] : 'application/vnd.openxmlformats-officedocument.wordprocessingml.document';
                    $row["DSCAMINHOARQ"] = $row["DSCAMINHOARQ"][0]["path"];
                }

                if ($row["IDPADRAO"] == "S") {
                    $this->documentoPropostaService->atualizarAnexoDocumentoProposta($row["NRSEQORCADOC"], $row["NMARQUIVO"], $row["VRTAMANHO"], $row["DSTIPO"], $row["DSCAMINHOARQ"]);
                }
            }

            parent::save($request, $response);
            $erro = $response->getError();
            if ($erro) {
                throw new \Exception($erro->getMessage(), 500);
            }
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    /**
     * @param Request\Row $request
     * @param Response $response
     */
    public function delete(Request $request, Response $response) {
        try {
            $row = $request->getRow();
            $dscaminhoarq = $row["DSCAMINHOARQ"];

            parent::delete($request, $response);

            if (!empty($dscaminhoarq)) {
                $this->zhFileUploader->deleteFile($dscaminhoarq);
            }

            $idpadrao = $row["IDPADRAO"];
            if ($idpadrao == "S") {
                $this->documentoPropostaService->atualizarAnexoDocumentoProposta($row["NRSEQORCADOC"], null, null, null, null);
            }

            $erro = $response->getError();
            if ($erro) {
                throw new \Exception($erro->getMessage(), 500);
            }
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    /**
     * @param Request\Row $request
     * @param Response $response
     */
    public function downloadDocFileServer(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrorcamentodocidioma = $row["NRORCAMENTODOCIDIOMA"];
            $nrorg = $this->environment->getNrOrg();

            $result = $this->docIdiomaService->downloadDocFileServer($nrorcamentodocidioma, $nrorg);
            $response->addDataSet(new DataSet("URLDOCUMENTO", array($result)));   
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    /**
     * @param Request\Row $request
     * @param Response $response
     */
    public function excluirAnexo(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrorcamentodocidioma = $row["NRORCAMENTODOCIDIOMA"];
            $dscaminhoarq         = $row["DSCAMINHOARQ"];
            $idpadrao             = $row["IDPADRAO"];
            
            $nrorg      = $this->environment->getNrOrg();
            $cdoperador = $this->environment->getCdOperador();
            
            $this->zhFileUploader->deleteFile($dscaminhoarq);
            $this->docIdiomaService->limparCamposAnexo($nrorcamentodocidioma, $nrorg, $cdoperador);

            if ($idpadrao == "S") {
                $this->documentoPropostaService->atualizarAnexoDocumentoProposta($row["NRSEQORCADOC"], null, null, null, null);
            }
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}