<?php

namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Remote\FileUploader\Server;
use Teknisa\SM\Service\Sm00024000ModeloDocumentosService;

class Sm00024000ModeloDocumentosController extends SMCrud {
    
    protected $dataSourceName = "fct_modelodoc_widget";
    protected $zhFileUploader;
    protected $modeloDocService;
    
	public function __construct ($crudService, $environment, Server $zhFileUploader, Sm00024000ModeloDocumentosService $modeloDocService) {
        parent::__construct($crudService, $environment);
        $this->zhFileUploader   = $zhFileUploader;
        $this->modeloDocService = $modeloDocService;
    }
    
    public function save(Request $request, Response $response) {
        try {
            $row = $request->getDataSet()->getRows()[0];
            if (isset($row["DSCAMINHOARQ"]) && is_array($row["DSCAMINHOARQ"])) {
                if (count($row["DSCAMINHOARQ"]) > 0) {
                    $row["NMARQUIVO"] = $row["DSCAMINHOARQ"][0]["name"];
                    $row["VRTAMANHO"] = round($row["DSCAMINHOARQ"][0]["size"] / 1024, 2);
                    $row["DSTIPO"] = ($row["DSCAMINHOARQ"][0]["type"]) ? $row["DSCAMINHOARQ"][0]["type"] : 'application/vnd.openxmlformats-officedocument.wordprocessingml.document';
                    $row["DSCAMINHOARQ"] = $row["DSCAMINHOARQ"][0]["path"];
                }
                else {
                    $row["DSCAMINHOARQ"] = "";
                }
            }
            
            parent::save($request, $response);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function validarInativarModelo (Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();

            $nrseqmoddocfct = $row['NRSEQMODDOCFCT'];
            $nrorg          = $row['NRORG'];

            $result = $this->modeloDocService->validarInativarModelo($nrseqmoddocfct, $nrorg);
            $response->addDataSet(new DataSet("contratosComModelo", $result));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function delete(Request $request, Response $response) {
        try {
            $row = $request->getRow();
            $dscaminhoarq = $row["DSCAMINHOARQ"];
            
            if (!empty($dscaminhoarq)) {
                $this->zhFileUploader->deleteFile($dscaminhoarq);
            }
            
            parent::delete($request, $response);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function excluirAnexo(Request $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrseqmoddocfct = $row["NRSEQMODDOCFCT"];
            $dscaminhoarq   = $row["DSCAMINHOARQ"];
            $nrorg          = $row["NRORG"];
            
            $this->zhFileUploader->deleteFile($dscaminhoarq);
            
            $this->modeloDocService->limparAnexoDoModelo($nrseqmoddocfct, $nrorg);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function downloadDocFileServer(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrseqmoddocfct = $row["NRSEQMODDOCFCT"];
            $nrorg = $this->environment->getNrOrg();
        
            $result = $this->modeloDocService->downloadDocFileServer($nrseqmoddocfct, $nrorg);
            $response->addDataSet(new DataSet("URLDOCUMENTO", array($result)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}

?>