/*-------------------------------------------------------------------------------------------------------------+
|                            						|
|   Trigger: PARAM_FILIAL    					|
|   Tabela: ParamFilial						|
|								|
|   Descrio: 							|
|   Sincroniza os campos de Gerente Operacional, Supervisor e Quantidade	|
|   de Funcionrios entre as tabelas HISTFILIAL e FILIAL			|
|                                   						|
|   Criao:                     						|
|   18/01/2008 - Luiz Passos     					|
|                                						|
+-------------------------------------------------------------------------------------------------------------*/

IF EXISTS(SELECT * FROM sysobjects O, sysusers U
	WHERE
		o.name = 'PARAM_FILIAL'		and
		type = 'TR'                and
		u.uid = o.uid              and
		u.name = USER)
		DROP TRIGGER PARAM_FILIAL
GO

CREATE TRIGGER PARAM_FILIAL
ON PARAMFILIAL
FOR INSERT, UPDATE
AS
	DECLARE	@V_DTREFERHIST	DATETIME;
	DECLARE	@V_CDGOPERACHIST	VARCHAR(12);  
	DECLARE	@V_CDSUPERVHIST	VARCHAR(12);
	DECLARE	@V_QTFUNCFILIHIST	NUMERIC;  
  
	DECLARE	@V_QTFUNCFILI    	NUMERIC;
	DECLARE	@V_CDGOPERAC     	VARCHAR(12);
	DECLARE	@V_CDSUPERVISOR  	VARCHAR(12);

	DECLARE	@V_MESPROC_OLD		VARCHAR(2);
	DECLARE	@V_MESPROC_NEW		VARCHAR(2);
	DECLARE	@V_ANOPROC_OLD		VARCHAR(4);
	DECLARE	@V_ANOPROC_NEW		VARCHAR(4);
	DECLARE	@V_CDFILIAL_NEW		VARCHAR(4);
	DECLARE	@V_CDFILIAL_OLD		VARCHAR(4);

BEGIN

	DECLARE C_PARAM CURSOR FOR

		SELECT
         CONVERT(VARCHAR,MONTH(DELETED.DTPROCESSA)),
			CONVERT(VARCHAR,YEAR(DELETED.DTPROCESSA)),
			DELETED.CDFILIAL,
			CONVERT(VARCHAR,MONTH(INSERTED.DTPROCESSA)),
			CONVERT(VARCHAR,YEAR(INSERTED.DTPROCESSA)),
			INSERTED.CDFILIAL
		FROM
			INSERTED,
			DELETED
		WHERE
			INSERTED.CDFILIAL = DELETED.CDFILIAL
		UNION ALL

		SELECT
			NULL,
			NULL,
			NULL,
			CONVERT(VARCHAR,MONTH(DTPROCESSA)),
			CONVERT(VARCHAR,YEAR(DTPROCESSA)),
			CDFILIAL
		FROM
			INSERTED
		WHERE
			CDFILIAL NOT IN (SELECT CDFILIAL FROM DELETED);

	OPEN C_PARAM;
	FETCH NEXT FROM C_PARAM INTO
		@V_MESPROC_OLD,
		@V_ANOPROC_OLD,
		@V_CDFILIAL_OLD,		
		@V_MESPROC_NEW,
		@V_ANOPROC_NEW,
		@V_CDFILIAL_NEW

   WHILE (@@FETCH_STATUS = 0) BEGIN

		IF NOT (@V_MESPROC_NEW IS NULL) AND ((ISNULL(@V_MESPROC_NEW,0)<>ISNULL(@V_MESPROC_OLD,0)) OR (ISNULL(@V_ANOPROC_NEW,0)<>ISNULL(@V_ANOPROC_OLD,0)))BEGIN

			IF (0 = (SELECT COUNT(CDFILIAL) FROM HISTFILIAL 
				WHERE (CONVERT(VARCHAR,MONTH(DTREFEHIST)) + CONVERT(VARCHAR,YEAR(DTREFEHIST))) = @V_MESPROC_NEW+@V_ANOPROC_NEW					
				AND CDFILIAL = @V_CDFILIAL_NEW)) BEGIN

				DECLARE C_FILIAL CURSOR FOR
					SELECT	CDGOPERAC, CDSUPERVISOR, QTFUNCFILI
					FROM 		FILIAL
					WHERE 	CDFILIAL = @V_CDFILIAL_NEW;
				OPEN C_FILIAL;
				FETCH NEXT FROM C_FILIAL INTO 
					@V_CDGOPERAC,
					@V_CDSUPERVISOR,
					@V_QTFUNCFILI;
				CLOSE C_FILIAL;
				DEALLOCATE C_FILIAL;
	
				INSERT INTO HISTFILIAL
      			(CDGOPERACHIST,
				   CDSUPERVHIST,
			       QTFUNCFILIHIST,
			       DTREFEHIST,
			       CDFILIAL)
				VALUES
			      (@V_CDGOPERAC,
				    @V_CDSUPERVISOR,
		      	 @V_QTFUNCFILI,
					 CONVERT(DATETIME,('01/'+@V_MESPROC_NEW+'/'+@V_ANOPROC_NEW),103),
   	   		 @V_CDFILIAL_NEW);    
			END
			ELSE BEGIN

				DECLARE C_HIST CURSOR FOR
					SELECT	CDGOPERACHIST, CDSUPERVHIST, QTFUNCFILIHIST
					FROM 		HISTFILIAL
					WHERE 	CDFILIAL = @V_CDFILIAL_NEW AND (CONVERT(VARCHAR,MONTH(DTREFEHIST))+CONVERT(VARCHAR,YEAR(DTREFEHIST))=@V_MESPROC_NEW+@V_ANOPROC_NEW);
				OPEN C_HIST;
				FETCH NEXT FROM C_HIST INTO 
					@V_CDGOPERACHIST,
					@V_CDSUPERVHIST,
					@V_QTFUNCFILIHIST;
				CLOSE C_HIST;
				DEALLOCATE C_HIST;


				UPDATE FILIAL SET
   	   		CDGOPERAC    = @V_CDGOPERACHIST,                  
	   		   CDSUPERVISOR = @V_CDSUPERVHIST,
   	   		QTFUNCFILI   = @V_QTFUNCFILIHIST
			   WHERE        
   	   		CDFILIAL = @V_CDFILIAL_NEW;
			END;
		END;

		FETCH NEXT FROM C_PARAM INTO
			@V_MESPROC_OLD,
			@V_ANOPROC_OLD,
			@V_CDFILIAL_OLD,		
			@V_MESPROC_NEW,
			@V_ANOPROC_NEW,
			@V_CDFILIAL_NEW
	END;

	CLOSE C_PARAM;
	DEALLOCATE C_PARAM;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'PARAM_FILIAL','5.01.007';
GO
